==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property simpleCriterion A property-based condition that defines a property, operator, and one or more values for including or excluding an S3 buckets from the job. (documented below)
 * @property tagCriterion A tag-based condition that defines the operator and tag keys or tag key and value pairs for including or excluding an S3 buckets from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd(
    public val simpleCriterion:
    ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndSimpleCriterion? = null,
    public val tagCriterion: ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterion? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd):
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd =
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd(
                simpleCriterion = javaType.simpleCriterion().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndSimpleCriterion.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tagCriterion = javaType.tagCriterion().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterion.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property simpleCriterion A property-based condition that defines a property, operator, and one or more values for including or excluding an S3 buckets from the job. (documented below)
 * @property tagCriterion A tag-based condition that defines the operator and tag keys or tag key and value pairs for including or excluding an S3 buckets from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd(
    public val simpleCriterion: ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndSimpleCriterion? = null,
    public val tagCriterion: ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterion? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd): ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd =
            ClassificationJobS3JobDefinitionBucketCriteriaExcludesAnd(
                simpleCriterion = javaType.simpleCriterion().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndSimpleCriterion.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tagCriterion = javaType.tagCriterion().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterion.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
